# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.5.2

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/v0.5.1...8901f99213d6eb01be6e06dd4ba35821972c2f5e))

### Maintenance and upkeep improvements

- Fix typo in `initFileSystem` method name [#52](https://github.com/jupyterlite/xeus-python-kernel/pull/52) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Remove leading space in the replite default example [#49](https://github.com/jupyterlite/xeus-python-kernel/pull/49) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- Update empack to 0.8.2 [#59](https://github.com/jupyterlite/xeus-python-kernel/pull/59) ([@martinRenou](https://github.com/martinRenou))
- Remove print statement [#58](https://github.com/jupyterlite/xeus-python-kernel/pull/58) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-06-28&to=2022-08-04&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Ajtpio+updated%3A2022-06-28..2022-08-04&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-06-28..2022-08-04&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.5.1

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/v0.5.0...974e729e0a90981e7a7c11a2428c13730a4a8d90))

### Bugs fixed

- Add a deduplication phase that make sure the latest copied labextension is used [#46](https://github.com/jupyterlite/xeus-python-kernel/pull/46) ([@martinRenou](https://github.com/martinRenou))
- Fix plugin id [#43](https://github.com/jupyterlite/xeus-python-kernel/pull/43) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Simplify the kernel spec [#44](https://github.com/jupyterlite/xeus-python-kernel/pull/44) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Update README with config options [#45](https://github.com/jupyterlite/xeus-python-kernel/pull/45) ([@martinRenou](https://github.com/martinRenou))
- Build docs for 0.5.0 [#42](https://github.com/jupyterlite/xeus-python-kernel/pull/42) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-06-27&to=2022-06-28&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Ajtpio+updated%3A2022-06-27..2022-06-28&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-06-27..2022-06-28&type=Issues)

## 0.5.0

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/v0.4.2...7c8676a97cf64b8c3d34bfa83de4536a86744358))

### Enhancements made

- Rename kernel to match classic xeus-python [#38](https://github.com/jupyterlite/xeus-python-kernel/pull/38) ([@martinRenou](https://github.com/martinRenou))
- Cleanup worker on dispose [#36](https://github.com/jupyterlite/xeus-python-kernel/pull/36) ([@martinRenou](https://github.com/martinRenou))

### Bugs fixed

- Fix post_build so that it populates the jupyter-lite.json properly [#40](https://github.com/jupyterlite/xeus-python-kernel/pull/40) ([@martinRenou](https://github.com/martinRenou))

### Maintenance and upkeep improvements

- Update empack [#39](https://github.com/jupyterlite/xeus-python-kernel/pull/39) ([@martinRenou](https://github.com/martinRenou))

### Other merged PRs

- Update docs so that it uses 0.4.2 [#31](https://github.com/jupyterlite/xeus-python-kernel/pull/31) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-06-21&to=2022-06-27&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Ajtpio+updated%3A2022-06-21..2022-06-27&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-06-21..2022-06-27&type=Issues)

## 0.4.2

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/v0.4.1...782da3882c5797985fe40fa40c730c1e59e3d06a))

### Bugs fixed

- Fix temporary directories cleanup so that it happens after the tasks [#34](https://github.com/jupyterlite/xeus-python-kernel/pull/34) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-06-20&to=2022-06-21&type=c))

[@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-06-20..2022-06-21&type=Issues)

## 0.4.1

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/v0.4.0...ca6a45ea13d665865e76cbf4741b3c193002237e))

### Bugs fixed

- Make sure xeus-python kernel emscripten build runs after the FederatedExtension addon [#32](https://github.com/jupyterlite/xeus-python-kernel/pull/32) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-06-20&to=2022-06-20&type=c))

[@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-06-20..2022-06-20&type=Issues)

## 0.4.0

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/v0.3.0...0da0c11690c0d065c2f33b63d88064aec0b79529))

### Enhancements made

- Update jupyterlite and enable file-system access [#27](https://github.com/jupyterlite/xeus-python-kernel/pull/27) ([@martinRenou](https://github.com/martinRenou))
- Fix conflicts with sys prefix packages and ignore ignore_sys_prefix flag [#23](https://github.com/jupyterlite/xeus-python-kernel/pull/23) ([@martinRenou](https://github.com/martinRenou))
- Toplevel await [#25](https://github.com/jupyterlite/xeus-python-kernel/pull/25) ([@DerThorsten](https://github.com/DerThorsten))
- Make xeus-python version configurable [#24](https://github.com/jupyterlite/xeus-python-kernel/pull/24) ([@martinRenou](https://github.com/martinRenou))
- Fix hanging jupyterlite build via jupyterlite-sphinx [#21](https://github.com/jupyterlite/xeus-python-kernel/pull/21) ([@benbovy](https://github.com/benbovy))

### Documentation improvements

- Improve docs [#28](https://github.com/jupyterlite/xeus-python-kernel/pull/28) ([@martinRenou](https://github.com/martinRenou))
- Update docs using 0.3.0 [#19](https://github.com/jupyterlite/xeus-python-kernel/pull/19) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-05-24&to=2022-06-20&type=c))

[@benbovy](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Abenbovy+updated%3A2022-05-24..2022-06-20&type=Issues) | [@bollwyvl](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Abollwyvl+updated%3A2022-05-24..2022-06-20&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Adavidbrochart+updated%3A2022-05-24..2022-06-20&type=Issues) | [@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3ADerThorsten+updated%3A2022-05-24..2022-06-20&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-05-24..2022-06-20&type=Issues)

## 0.3.0

([Full Changelog](https://github.com/jupyterlite/xeus-python-kernel/compare/8166fc63fd8b4f56b39431e810dabbeae842ea83...280c7c60b77d19a161de8256ccda7b77235f5690))

### Merged PRs

- Reduce sdist size [#17](https://github.com/jupyterlite/xeus-python-kernel/pull/17) ([@martinRenou](https://github.com/martinRenou))
- Update emsdk and empack [#16](https://github.com/jupyterlite/xeus-python-kernel/pull/16) ([@martinRenou](https://github.com/martinRenou))
- Remove duplication of the labextension [#15](https://github.com/jupyterlite/xeus-python-kernel/pull/15) ([@martinRenou](https://github.com/martinRenou))
- Rebuild with latest empack [#13](https://github.com/jupyterlite/xeus-python-kernel/pull/13) ([@martinRenou](https://github.com/martinRenou))
- Add back Changelog [#11](https://github.com/jupyterlite/xeus-python-kernel/pull/11) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-python-kernel/graphs/contributors?from=2022-05-19&to=2022-05-24&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3Ajtpio+updated%3A2022-05-19..2022-05-24&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-python-kernel+involves%3AmartinRenou+updated%3A2022-05-19..2022-05-24&type=Issues)

## v0.2.0

### What's Changed

- Add docs by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/4
- Fix build by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/5
- Add Matplotlib to the env by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/7
- Do not use xeus-python's master branch by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/8
- Simplify dockerfile by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/9
- Xeus python build addon by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/10

**Full Changelog**: https://github.com/jupyterlite/xeus-python-kernel/compare/0.1.0...0.2.0

## v0.1.0

### Contributions

- Initial version by @DerThorsten in https://github.com/jupyterlite/xeus-python-kernel/commit/d28dbc1ec9c1dca3f861d79ee5930054c00d5998
- Remove sleep + renames according to https://github.com/jupyter-xeus/xeus-python/pull/530 by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/1
- Fix README by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/2
- Add Docker build by @martinRenou in https://github.com/jupyterlite/xeus-python-kernel/pull/3

### Contributors

- @DerThorsten started the project
- @martinRenou made their first contribution in https://github.com/jupyterlite/xeus-python-kernel/pull/1

**Full Changelog**: https://github.com/jupyterlite/xeus-python-kernel/commits/0.1.0
